#====================================================================
# Chooser script demo and documentation -- Mike Ter Louw
#====================================================================
clear

# Welcome to the Chooser script.  This script will allow you to create
# simple lists of items for the user to choose from.  Here are some of
# the key features:
#
#	- Lists can contain up to 100 items.
#	- List items can have up to four lines of description text.
#	- Keyboard and mouse user interface.
#	- Fancy shmancy fully-working scroll bar.
#	- Customizable color scheme and menu dimensions.
#	- Can be invoked multiple times, for multiple lists.
#	- Can be integrated into other menu scripts.

# A Note On Scalability / Run-Speed
#
# While this script is powerful, it probably doesn't scale very well.
# If you notice the script running slow, you might be bogging it down
# with too many lists or too many descriptions or something.  The bottom
# line is that CD Shell variable expansion slows down when too many
# variables are defined, so if things are getting slow, simplify your
# lists and you should see performance improve.

#--------------------------------------------------------------------------

# How To Use It
#
# The chooser was designed to require very little overhead to get you
# up and running.  Most features have default settings, so unless you
# override them, you don't have to mess with much.  Although this script
# looks huge at first glance, if you take out all the comments it is only
# about 30 lines of code.  Now let's go through the various settings and
# steps required to run the chooser.

# Optimizing For Speed
#
# One thing that we should do first is run the chooser optimizer script.
# This step is optional, but you will probably want to do it because it
# will increase the responsiveness of the chooser.  You should run the
# optimizer as early as possible in your script, and it is only needed
# once, even if you invoke the chooser multiple times.

# The chooser will call your script again when it has finished optimizing,
# so we need to check to see if this is the case.  If so, we skip the
# call to the optimization script.

if (defined[c.prep.done]); then goto optimized


# We have to tell the optimizer the name of our script, so that it can
# call us back when it's finished...

set c.prep.return = "runme.cds"


# Now run the optimizer...

script ch_prep.cds
optimized:

#--------------------------------------------------------------------------

# Just ignore the following line for now, it will be made clear later.
if ($c.finished); then goto start

#--------------------------------------------------------------------------

# Chooser Behavior Settings
#
# You'll have to configure the following settings in order to run the
# chooser.  They should all be pretty self-explanatory, except maybe for
# the list name.  We'll take a closer look at that one in the next section.

set chooser = "kernel"					# Name of list to choose from
set c.path = "/boot/scripts/chooser"	# Path to "chooser.cds" script file
set c.onExit = "runme.cds"				# Script to call on exit
set c.allowEscape = 0					# Allow escape key to terminate chooser

# Using the Mouse
#
# The chooser script can utilize the mouse if it is detected by CD Shell.
# You do not have to use it though, so this parameter is optional.

set c.mouse = 1			# 0 = disable mouse (default), 1 = enable mouse

#--------------------------------------------------------------------------

# Defining a List Array
#
# We now need a list of items to display in the chooser.  Keep the
# following rules in mind when making your list.
#
#	- Item numbering starts at zero.
#	- A display name is required for each item.
#	- The item message is optional (up to 4 lines, max line size = 68 chars).
#	- The list size parameter is required.

# That being said, let's go ahead and define a simple list.  First thing,
# remember the list name we assigned to the $chooser variable?  That is
# the identifier used to build our array of list items.  Since we're calling
# the list "kernels", we have to name all of our variables using that name.

# The first of these variables is the list size.  It simply lets the chooser
# know how many items are in the list.
set kernel.size = 20

# Here's the first item in our list.  Notice that it has a name, four lines
# of description text, and a value.  The value is optional.  If defined, it
# will tell the chooser what to report as the selected item, should this one
# be chosen by the user.  The chooser will also let you know which item
# number was selected, as we'll see later.
set kernel.0.name = "Knoppix"
set kernel.0.msg.0 = "If you select this option, you would expect the menu to launch the"
set kernel.0.msg.1 = "Knoppix Linux distribution.  However this menu won't do that for you,"
set kernel.0.msg.2 = "it will only tell you what you selected.  Similarly, this message is"
set kernel.0.msg.3 = "equally useless, I just wanted to show a really long message. :)"
set kernel.0.value = "Knoppix version 3.7"

# Now lets define some more items to complete the list.  We won't go crazy
# defining optional parameters for these, but you can feel free to do so.  ;)
set kernel.1.name = "Ubuntu"
set kernel.2.name = "Gentoo"
set kernel.3.name = "Red Hat"
set kernel.4.name = "Centos"
set kernel.5.name = "Mandrake"
set kernel.6.name = "Fedora Core 3"
set kernel.7.name = "Suse"
set kernel.8.name = "FreeBSD"
set kernel.9.name = "NetBSD"
set kernel.10.name = "Yellow Dog"
set kernel.11.name = "OpenBSD"
set kernel.12.name = "Debian"
set kernel.13.name = "KnoppMyth"
set kernel.14.name = "Slackware"
set kernel.15.name = "Solaris"
set kernel.16.name = "AIX"
set kernel.17.name = "Running out of ideas"
set kernel.18.name = "Xandros"
set kernel.19.name = "Can I stop now?"

#--------------------------------------------------------------------------

# Invoking the Chooser
#
# Now that we have the necessary items set up, we can invoke the
# chooser and let the user pick one of them.  When the user either
# selects an item or escapes the menu, the onExit script will be
# called with some variables set to let us know the result.

# Since this script will be called back when the chooser terminates,
# let's check for that condition here.

start:
if ($c.finished);

	# You'll need to reset this value every time the chooser completes.
	then set c.finished = 0

	# Clearing the screen is up to you.
	then clear

	# Let's show the item that was chosen, then end the script.
	then print "You selected $($(chooser).$(c.selected).name)\n"
	then end

	# You can also query the variables $c.escaped and $c.value to find
	# out whether the user actually selected an item or just pressed the
	# escape key, and the value of the item selected.

# You can uncomment the following line if you want to play with the
# customization settings in the next section.

# call customize


# Okay, let's finally run the chooser.
script chooser.cds

#--------------------------------------------------------------------------

# Customization
#
# The following code shows all of the customization options that are
# available.  Note that for each section, if you set the "custom" variable
# to 1, you'll have to define every option in that section.
#
# You are also free to draw your own title bar at the top and status bar
# at the bottom, as the chooser leaves these areas of the screen untouched
# for such purposes.

customize:

# Background properties.
set bg.custom = 1
set bg.char = " "	# Character used to tile the background.
set bg.color = color[white on white]

# List (menu) window properties.
set c.menu.custom = 1	# Indicate that we don't want the default settings.
set c.menu.width = 40	# Max = 76, Min = longest menu item name + 4
set c.menu.height = 11	# Max = 13, Min = 5
set c.menu.win.color = color[white on brightblue]
set c.menu.shadow.color = color[grey on white]
set c.scroll.color = color[yellow on brightblue]
set c.menu.text.color = color[white on brightblue]
set c.menu.selected.color = color[white on blue]
set c.menu.clicked.color = color[white on red]

# Message window properties.
set c.msg.custom = 1
set c.msg.win.color = color[white on brightgrey]
set c.msg.shadow.color = color[grey on white]
set c.msg.text.color = color[grey on brightgrey]

return

#--------------------------------------------------------------------------
